pub async fn upsert_runtime_snapshot<'e, E>(
executor: E,
snapshot: &RuntimeSnapshotInput,
) -> Result<(), AwaError>where
E: PgExecutor<'e>,Expand description
Upsert a runtime observability snapshot for one worker instance.
pub async fn upsert_runtime_snapshot<'e, E>(
executor: E,
snapshot: &RuntimeSnapshotInput,
) -> Result<(), AwaError>where
E: PgExecutor<'e>,Upsert a runtime observability snapshot for one worker instance.