Module postgres

Module postgres 

Postgres adapter helpers.

Re-exports

pub use crate::insert::prepare_job_insert;
pub use crate::insert::prepare_raw_job_insert;
pub use crate::insert::PreparedJobInsert;

Constants

INSERT_JOB_SQL
Canonical SQL for inserting one prepared Awa job through a Postgres driver that binds state and unique state masks as text.
UNIQUE_VIOLATION_SQLSTATE
SQLSTATE for Postgres unique-violation errors.